==> 2.4.6.tar.gz: lib/src/models/method_names.dart <==
enum FireworkSDKMethodName {
  sdkInit("fw:sdk-init"),
  customCTAClick("fw:custom-cta-click"),
  videoPlayback("fw:video-playback"),
  videoFeedClick("fw:video-feed-click"),
  nativeAppLanguageUpdated("fw:native-app-language-updated");

  final String rawName;
  const FireworkSDKMethodName(this.rawName);
}

enum FireworkSDKNativeMethodName {
  init,
  openVideoPlayer,
  setCustomCTAClickEnabled,
  setVideoPlaybackEventEnabled,
  setShareBaseURL,
  setAdBadgeConfiguration,
  trackPurchase,
  changeAppLanguage,
  pausePlayer,
  resumePlayer,
  markInitCalled,
}

enum ShoppingMethodName {
  updateProductDetails("fw:shopping:update-product-details"),
  ctaButtonClick("fw:shopping:cta-button-click"),
  clickCartIcon("fw:shopping:click-cart-icon"),
  customLinkButtonClick("fw:shopping:custom-link-button-click"),
  customProductCardTap("fw:shopping:custom-product-card-tap");

  final String rawName;
  const ShoppingMethodName(this.rawName);
}

enum ShoppingNativeMethodName {
  init,
  setCartIconVisible,
  setCartItemCount,
  setProductInfoViewConfiguration,
  setCustomClickLinkButtonEnabled,
  setCustomTapProductCardEnabled,
  showShoppingCTALoader,
  completeShoppingCTAHandlingProcess,
}

enum VideoFeedMethodName {
  onVideoFeedLoadFinished("onVideoFeedLoadFinished"),
  onVideoFeedEmpty("onVideoFeedEmpty"),
  onVideoFeedDidStartPictureInPicture("onVideoFeedDidStartPictureInPicture"),
  onVideoFeedDidStopPictureInPicture("onVideoFeedDidStopPictureInPicture");

  final String rawName;
  const VideoFeedMethodName(this.rawName);
}

enum VideoFeedNativeMethodName {
  setVideoFeedConfiguration,
  setVideoPlayerConfiguration,
  refresh,
  setMarginRight,
}

enum LiveStreamMethodName {
  onLiveStreamEvent("fw:livestream"),
  onLiveStreamChatEvent("fw:livestream-chat");

  final String rawName;
  const LiveStreamMethodName(this.rawName);
}

enum LiveStreamNativeMethodName {
  init,
}

enum NavigatorNativeMethodName {
  popNativeContainer,
  startFloatingPlayer,
  stopFloatingPlayer,
}

enum StoryBlockMethodName {
  onStoryBlockLoadFinished("onStoryBlockLoadFinished"),
  onStoryBlockEmpty("onStoryBlockEmpty"),
  onStoryBlockPdpVisibilityChange("onStoryBlockPdpVisibilityChange"),
  onStoryBlockDidStartPictureInPicture("onStoryBlockDidStartPictureInPicture"),
  onStoryBlockDidStopPictureInPicture("onStoryBlockDidStopPictureInPicture");

  final String rawName;
  const StoryBlockMethodName(this.rawName);
}

enum StoryBlockNativeMethodName {
  play,
  pause,
  setMarginRight,
  setStoryBlockConfiguration,
  showIvsPlayerView,
  hideIvsPlayerView,
  removeIvsPlayerView,
  playIvsPlayer,
  pauseIvsPlayer,
  onViewportEntered,
  onViewportLeft,
  openFullscreen,
}

==> 2.8.0.tar.gz: lib/src/models/method_names.dart <==
enum FireworkSDKMethodName {
  sdkInit("fw:sdk-init"),
  customCTAClick("fw:custom-cta-click"),
  videoPlayback("fw:video-playback"),
  videoFeedClick("fw:video-feed-click"),
  nativeAppLanguageUpdated("fw:native-app-language-updated");

  final String rawName;
  const FireworkSDKMethodName(this.rawName);
}

enum FireworkSDKNativeMethodName {
  init,
  openVideoPlayer,
  setCustomCTAClickEnabled,
  setVideoPlaybackEventEnabled,
  setShareBaseURL,
  setAdBadgeConfiguration,
  trackPurchase,
  changeAppLanguage,
  pausePlayer,
  resumePlayer,
  markInitCalled,
}

enum ShoppingMethodName {
  updateProductDetails("fw:shopping:update-product-details"),
  ctaButtonClick("fw:shopping:cta-button-click"),
  clickCartIcon("fw:shopping:click-cart-icon"),
  customLinkButtonClick("fw:shopping:custom-link-button-click"),
  customProductCardTap("fw:shopping:custom-product-card-tap");

  final String rawName;
  const ShoppingMethodName(this.rawName);
}

enum ShoppingNativeMethodName {
  init,
  setCartIconVisible,
  setCartItemCount,
  setProductInfoViewConfiguration,
  setCustomClickLinkButtonEnabled,
  setCustomTapProductCardEnabled,
  showShoppingCTALoader,
  completeShoppingCTAHandlingProcess,
}

enum VideoFeedMethodName {
  onVideoFeedLoadFinished("onVideoFeedLoadFinished"),
  onVideoFeedEmpty("onVideoFeedEmpty"),
  onVideoFeedDidStartPictureInPicture("onVideoFeedDidStartPictureInPicture"),
  onVideoFeedDidStopPictureInPicture("onVideoFeedDidStopPictureInPicture"),
  onVideoFeedGetFeedId("onVideoFeedGetFeedId");

  final String rawName;
  const VideoFeedMethodName(this.rawName);
}

enum VideoFeedNativeMethodName {
  setVideoFeedConfiguration,
  setVideoPlayerConfiguration,
  refresh,
  setMarginRight,
}

enum LiveStreamMethodName {
  onLiveStreamEvent("fw:livestream"),
  onLiveStreamChatEvent("fw:livestream-chat");

  final String rawName;
  const LiveStreamMethodName(this.rawName);
}

enum LiveStreamNativeMethodName {
  init,
}

enum NavigatorNativeMethodName {
  popNativeContainer,
  startFloatingPlayer,
  stopFloatingPlayer,
}

enum StoryBlockMethodName {
  onStoryBlockLoadFinished("onStoryBlockLoadFinished"),
  onStoryBlockEmpty("onStoryBlockEmpty"),
  onStoryBlockPdpVisibilityChange("onStoryBlockPdpVisibilityChange"),
  onStoryBlockDidStartPictureInPicture("onStoryBlockDidStartPictureInPicture"),
  onStoryBlockDidStopPictureInPicture("onStoryBlockDidStopPictureInPicture"),
  onStoryBlockGetFeedId("onStoryBlockGetFeedId");

  final String rawName;
  const StoryBlockMethodName(this.rawName);
}

enum StoryBlockNativeMethodName {
  play,
  pause,
  setMarginRight,
  setStoryBlockConfiguration,
  showIvsPlayerView,
  hideIvsPlayerView,
  removeIvsPlayerView,
  playIvsPlayer,
  pauseIvsPlayer,
  onViewportEntered,
  onViewportLeft,
  openFullscreen,
}
